# Python package for statistical disclosure control

This package implements a Python wrapper for easy use of the functions in the `GaussSuppression` and `SmallCountRounding` R packages. This package does not support the full functionality of the R packages, and is currently in alpha testing. For some ugly documentation, see [here](https://solid-adventure-n15ynzy.pages.github.io/). Alternatively, see an introduction in [this Jupyter notebook](https://github.com/statisticsnorway/ssbkonf/blob/main/docs/intro.ipynb).
